/* @file
 * @brief This module understands how to parse and encode protocols
 *
 * This is where we read input lines of format squid25, squid26, etc.  And this
 * is where we output lines of the same format.
 *
 * This module also knows how to figure out whether a line is properly
 * formatted.
 *
 * Netsweeper Squid URL Redirector
 * This application is designed to work with the Netsweeper Internet Content
 * Filtering System.
 *
 * Copyright 2010 Netsweeper Inc. All Rights Reserved.
 * Netsweeper, Netsweeper Inc. is either a copyrighted or registered trademark
 * of Netsweeper Inc.
 */

#ifndef PROTOCOL_H_INCLUDED
#define PROTOCOL_H_INCLUDED

#include "stddef.h"
#include "simple_iplist.h"
#include "redir.h"

#define MAX_PROTOCOLS_OTHER_OPTIONS 20

typedef struct {
	char *req_id;
	char *url;
	char *IP;
	char *username;
	char *method;
	char *group;
	char *otheroptions[MAX_PROTOCOLS_OTHER_OPTIONS];
	/* contains full contents of input line */
	char line_buffer[];
} protocol_input_line;

int protocol_config_nametoprotocol(const char *name, protocol_select *protocol);
const char *protocol_config_protocoltoname (protocol_select protocol);
int protocol_parse (const char *inputstr, protocol_input_line **parsed_line, protocol_select protocol);
int protocol_encode (GlobalConf *conf, const protocol_input_line *parsed_line, char *line_buffer, size_t line_buffer_len, protocol_select protocol);
int protocol_mangle_username (protocol_input_line *parsed_line, GlobalConf *conf);
int protocol_replace_badchars(GlobalConf *conf, protocol_input_line *parsed_line);
void protocol_lowercase_username (protocol_input_line *parsed_line);
void protocol_parsed_line_destroy (protocol_input_line *parsed_line);
void protocol_append_domain(struct simple_iphead *iplist,  protocol_input_line *parsed_line);

#endif
